# more_widgets
Add more widgets to use in your apps...

## List of widgets :
### GradientBackground :
Shows a gradient background container. Here is the parameters list:
```dart
final Widget child;
final List<Color> colors;       // Default : const [Color(0xffff9800), Color(0xfff44336)]
final List<Color> darkColors;   // Default : const [Color(0xff13191f), Color(0xff262f3c)]
final List<double> stops;       // Default : const [0.2, 0.8]
final AlignmentGeometry begin;  // Default : FractionalOffset.topLeft
final AlignmentGeometry end;    // Default : FractionalOffset.bottomRight
final bool useDarkMode;         // Default : true
```


### RoundedContainer :
Shows a rounded container. The default color is white. Here is the parameters list:
```dart
final Widget? child;
final Color color;            // Default : Colors.white
final double circularRadius;  // Default : 20
final double margin;          // Default : 20
final double padding;         // Default : 20
```

## List of dialogs :
Those dialogs adapt automatically to the OS and display accordingly.

### Dialogs.infoDialog
This shows an informative dialog with only one button. Here is the parameters list:

```dart
required BuildContext context,
required String title,
required String message,
String buttonText = "Ok",
bool popByDefault = true,
Function? onPressed,
```


| iOS                                | Android (with material design 3)           |
|------------------------------------|--------------------------------------------|
| ![iOS](assets/info_dialog_iOS.png) | ![Android](assets/info_dialog_android.png) |

### Dialogs.dialogWithOptions
Here is the dialog with options, it's useful if you want to pop up a dialog where you can choose between 
two options. One of them can be set as destructive action. Here is the parameters list:

```dart
required BuildContext context,
required String title,
required String message,
String textLeftButton = 'OK',
String textRightButton = 'Cancel',
Function? onPressedLeftButton,
Function? onPressedRightButton,
DestructiveAction destructiveAction = DestructiveAction.right,
DefaultAction defaultAction = DefaultAction.none,
Color androidDestructiveColor = Colors.red,
bool popByDefault = true,
```


| iOS                                        | Android (with material design 3)                   |
|--------------------------------------------|----------------------------------------------------|
| ![iOS](assets/dialog_with_options_iOS.png) | ![Android](assets/dialog_with_options_android.png) |

### Dialogs.textInputDialog
This method will display a dialog with one or two buttons that have actions. Here is the parameters list:

```dart
required BuildContext context,
required String title,
required String message,
String textLeftButton = 'OK',
String textRightButton = 'Cancel',
Function? onPressedLeftButton,
Function? onPressedRightButton,
DestructiveAction destructiveAction = DestructiveAction.right,
DefaultAction defaultAction = DefaultAction.none,
Color androidDestructiveColor = Colors.red,
bool popByDefault = true,
bool hasSecondaryButton = true,
String? placeholder,
TextEditingController? controller,
TextInputType? keyboardType,
Function? onChanged,
Function? onEditingComplete,
```
| iOS                                      | Android (with material design 3)                 |
|------------------------------------------|--------------------------------------------------|
| ![iOS](assets/text_input_dialog_iOS.png) | ![Android](assets/text_input_dialog_android.png) |

### Dialogs.loadingDialog
This method will display a dialog with a loading indicator inside. Here is the parameters list:

```dart
required BuildContext context,
String? title,
```

| iOS                                   | Android (with material design 3)              |
|---------------------------------------|-----------------------------------------------|
| ![iOS](assets/loading_dialog_iOS.png) | ![Android](assets/loading_dialog_android.png) |

## Left to do
- [ ] Adapt dialogs design to MacOS
- [ ] Adapt dialogs design to Windows
- [ ] Adapt dialogs design to Linux
- [ ] Improve code documentation